@@ -837,7 +837,8 @@ read_hex_digits (const char *ptr, int chars)
 {
 	char buf[16];
 	g_assert (chars + 1 < sizeof (buf));
-	strncpy (buf, ptr, chars);
+	memcpy (buf, ptr, chars);
+	buf[chars] = 0;
 	return strtol (buf, 0, 16);
 }
 
